@@ -39,7 +39,7 @@ class PostAdminForm(admin.ModelAdmin):
 
     # https://docs.djangoproject.com/en/dev/ref/contrib/admin/#django.contrib.admin.ModelAdmin.filter%5Fhorizontal
     if "rgallery" in conf.INSTALLED_APPS:
-        filter_horizontal = ['photo']
+        filter_horizontal = ['photo', 'video']
 
     # http://www.b-list.org/weblog/2008/dec/24/admin/
     def save_model(self, request, obj, form, change):
