@@ -18,9 +18,9 @@ urlpatterns = patterns('',
     url(r'^tag-(?P<tag>[-_A-Za-z0-9]+)/feed.rss$', TagFeed(), {}, 'app_blog-tagfeed2'),
     url(r'^feed/$',                                AllFeed(), {}, 'app_blog-feed'),
     url(r'^feed.rss$',                             AllFeed(), {}, 'app_blog-feed2'),
-    # 1 day cache
-    url(r'^ajax/testing/$',                        (AJAXArchive.as_view()), {}, 'app_blog-ajaxarchive'),
-    url(r'^archive/$',                             (AJAXArchive.as_view()), {}, 'app_blog-archive'),
+    # 7 days cache
+    url(r'^ajax/testing/$',                        cache_page(60 * 24 * 7)(AJAXArchive.as_view()), {}, 'app_blog-ajaxarchive'),
+    url(r'^archive/$',                             cache_page(60 * 24 * 7)(AJAXArchive.as_view()), {}, 'app_blog-archive'),
 )
 
 
