@@ -60,6 +60,9 @@ class PostDetailView(MetaSidebar, DetailView):
     def get_object(self):
         self.obj = get_object_or_404(mymodels.Post, slug=self.kwargs['slug'], status=1)
         self.obj.hits = self.obj.hits + 1
+        prefix = "http://"
+        if self.request.is_secure():
+            prefix = "https://"
         current_site = get_current_site(self.request)
         current_url = reverse('app_blog-post-detail', kwargs={'slug': self.kwargs['slug']})
         # Si esta activado DISQUS_SYNC rellenamos el thread_id vía API
@@ -69,14 +72,14 @@ class PostDetailView(MetaSidebar, DetailView):
                     try:
                         #print 'link:http://'+current_site.domain+current_url
                         api = DisqusAPI(conf.DISQUS_API_SECRET, conf.DISQUS_API_PUBLIC)
-                        dq_response = api.threads.details(forum=conf.DISQUS_WEBSITE_SHORTNAME, thread='link:http://'+current_site.domain+current_url)
+                        dq_response = api.threads.details(forum=conf.DISQUS_WEBSITE_SHORTNAME, thread='link:'+prefix+current_site.domain+current_url)
                         self.obj.thread_id = dq_response['id']
                     except:
                         pass
                     try:
                         #print 'link:http://www.'+current_site.domain+current_url
                         api = DisqusAPI(conf.DISQUS_API_SECRET, conf.DISQUS_API_PUBLIC)
-                        dq_response = api.threads.details(forum=conf.DISQUS_WEBSITE_SHORTNAME, thread='link:http://www.'+current_site.domain+current_url)
+                        dq_response = api.threads.details(forum=conf.DISQUS_WEBSITE_SHORTNAME, thread='link:'+prefix+'www.'+current_site.domain+current_url)
                         self.obj.thread_id = dq_response['id']
                     except:
                         pass
